@@ -667,14 +667,32 @@ class Sf:
 
         def record_type_picklist_retriever(self, object, record_type_id, record_type_name):
             result = []
-            for key, value in self.sf_api_call(f"/services/data/{self.api_version}/ui-api/object-info/{object}/picklist-values/{record_type_id}")['picklistFieldValues'].items():
+            picklist_metadata = self.sf_api_call(f"/services/data/{self.api_version}/ui-api/object-info/{object}/picklist-values/{record_type_id}")['picklistFieldValues']
+            if len(picklist_metadata) == 0:
+                return pd.DataFrame(columns=['attributes',
+                                    'label',
+                                    'validFor',
+                                    'value',
+                                    'Field_API',
+                                    'defaultValueLabel',
+                                    'defaultValueValue',
+                                    'Controlling Field',
+                                    'RecordTypeName',
+                                    'Object'])
+                
+            for key, value in picklist_metadata.items():
                 result.append({"Field_API": key, "controllerValues": value['controllerValues'], "defaultValue":  value['defaultValue'], "values": value['values']})
             final_result_pd = json_normalize(result, ['values'], ['defaultValue', 'controllerValues', 'Field_API'])
             ## Converts the validFor numerical codes i.e. [0,2] to it's corresponding text values by looking it up on the controllerValues column i.e. {'Web': 0, 'Phone Inquiry': 1, 'Partner Reference': 2 ... }
             ## [0,2] -> ['Web', 'Partner Reference']
             final_result_pd['validFor'] = final_result_pd.apply(lambda row: "\n".join([{v: k for k, v in row['controllerValues'].items()}[value] for value in row['validFor']]), axis=1)
             final_result_pd.drop(columns=['controllerValues'], inplace=True)
-            final_result_pd[['defaultValueLabel', 'defaultValueValue']] = json_normalize(final_result_pd['defaultValue'])[['label','value']]
+            
+            try:
+                final_result_pd[['defaultValueLabel', 'defaultValueValue']] = json_normalize(final_result_pd['defaultValue'])[['label','value']]
+            except:
+                final_result_pd[['defaultValueLabel', 'defaultValueValue']] = [np.nan, np.nan]
+            
             final_result_pd.drop(columns=['defaultValue'], inplace=True)
             final_result_pd = pd.merge(final_result_pd, controlling_fields, left_on='Field_API', right_on='Field', how='left').drop(columns=['Field']).copy()
             final_result_pd['RecordTypeName'] = record_type_name
@@ -686,6 +704,7 @@ class Sf:
         results = results[['Object', 'RecordTypeName', 'Field_API', 'Controlling Field', 'defaultValueLabel', 'defaultValueValue', 'label', 'value', 'validFor']]
         return results
 
+
     async def object_permission_bulk_check(self, objects: list, permissions: list ):
         async_object_permission_check = async_wrap(self.object_permission_check)
         result_list = await asyncio.gather(*[async_object_permission_check(object, permission ) for object in objects for permission in permissions])
